==> auto-ui-2.1.28.tgz: package/es/tabs/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import './style.scss';
var TabsItem = function (props) {
    var active = props.active, value = props.value, className = props.className, onClick = props.onClick, children = props.children, otherProps = __rest(props, ["active", "value", "className", "onClick", "children"]);
    var composeClassName = cn('x-tabs__item', {
        'x-tabs--active': !!active,
    }, className);
    var onAClick = function () {
        onClick(value);
    };
    return (React.createElement("button", __assign({}, otherProps, { className: composeClassName, onClick: onAClick }), children));
};
var Tabs = /** @class */ (function (_super) {
    __extends(Tabs, _super);
    function Tabs() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ref = React.createRef();
        _this.animTimer = 0;
        _this.state = {
            currentActive: -2,
            runAnim: false,
        };
        _this.onTransitionEnd = function () {
            clearTimeout(_this.animTimer);
            if (_this.ref && _this.ref.current) {
                var dom = _this.ref.current;
                var line = dom.querySelector('.x-tabs__line');
                for (var i = 0; i < dom.children.length; i++) {
                    if (dom.children[i].classList.contains('x-tabs--active')) {
                        dom.children[i].classList.add('x-tabs--line');
                        _this.setState({
                            currentActive: i,
                        });
                        break;
                    }
                }
                if (line) {
                    line.style.display = 'none';
                }
                _this.setState({
                    runAnim: false,
                });
            }
        };
        return _this;
    }
    Tabs.prototype.componentDidMount = function () {
        if (this.ref && this.ref.current) {
            var dom = this.ref.current;
            for (var i = 0; i < dom.children.length; i++) {
                if (dom.children[i].classList.contains('x-tabs--active')) {
                    dom.children[i].classList.add('x-tabs--line');
                    this.setState({
                        currentActive: i,
                    });
                    break;
                }
            }
        }
    };
    Tabs.prototype.componentDidUpdate = function () {
        if (this.state.runAnim) {
            return;
        }
        if (this.ref && this.ref.current) {
            var dom = this.ref.current;
            var line_1 = dom.querySelector('.x-tabs__line');
            var currentX_1 = 0;
            var targetX_1 = 0;
            var moveLine = function () {
                var duration = 0.3;
                if (Math.abs(targetX_1 - currentX_1) < 90) {
                    duration = 0.15;
                }
                line_1.style.transform = "translate(" + targetX_1 + "px, 0)";
                line_1.style.transition = "transform " + duration + "s ease-out";
                line_1.style.animation = "__x_tabs_line_scale " + duration + "s ease-out";
            };
            for (var _i = 0, _a = dom.children; _i < _a.length; _i++) {
                var item = _a[_i];
                if (item.classList.contains('x-tabs--active')) {
                    var cur = dom.children[this.state.currentActive];
                    currentX_1 = cur ? cur.offsetLeft + cur.clientWidth / 2 : -300;
                    targetX_1 = item.offsetLeft + item.clientWidth / 2;
                    if (currentX_1 !== targetX_1 && line_1) {
                        line_1.style.transform = "translate(" + currentX_1 + "px, 0)";
                        line_1.style.transition = 'none';
                        line_1.style.animation = 'none';
                        line_1.style.display = 'block';
                        this.setState({
                            runAnim: true,
                        });
                        clearTimeout(this.animTimer);
                        this.animTimer = setTimeout(this.onTransitionEnd, 400);
                        setTimeout(moveLine, 10);
                    }
                    break;
                }
            }
        }
    };
    Tabs.prototype.render = function () {
        var _this = this;
        var _a = this.props, className = _a.className, children = _a.children, active = _a.active, onClick = _a.onClick, shrink = _a.shrink, otherProps = __rest(_a, ["className", "children", "active", "onClick", "shrink"]);
        var composeClassName = cn('x-tabs', {
            'x-tabs--shrink': shrink,
        }, className);
        var composeChildren = [];
        if (Array.isArray(children)) {
            composeChildren.push.apply(composeChildren, children);
        }
        else {
            composeChildren.push(children);
        }
        composeChildren = composeChildren.map(function (res, index) {
            var act = _this.props.hasOwnProperty('active') && res.props.value === active;
            return React.cloneElement(res, {
                active: act,
                key: index,
                value: res.props.value,
                onClick: function (value) {
                    if (_this.state.runAnim) {
                        return;
                    }
                    console.log(_this.state.runAnim);
                    onClick(value);
                },
                children: res.props.children,
            });
        });
        return (React.createElement("div", __assign({}, otherProps, { className: composeClassName, ref: this.ref }),
            React.createElement("sub", { className: "x-tabs__line", style: { display: 'none' }, onTransitionEnd: this.onTransitionEnd }),
            composeChildren));
    };
    return Tabs;
}(React.PureComponent));
Tabs.Item = TabsItem;
export default Tabs;

==> auto-ui-2.1.34.tgz: package/es/tabs/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import './style.scss';
var TabsItem = function (props) {
    var active = props.active, value = props.value, className = props.className, onClick = props.onClick, children = props.children, otherProps = __rest(props, ["active", "value", "className", "onClick", "children"]);
    var composeClassName = cn('x-tabs__item', {
        'x-tabs--active': !!active,
    }, className);
    var onAClick = function () {
        onClick(value);
    };
    return (React.createElement("button", __assign({}, otherProps, { className: composeClassName, onClick: onAClick }), children));
};
var Tabs = /** @class */ (function (_super) {
    __extends(Tabs, _super);
    function Tabs() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ref = React.createRef();
        _this.animTimer = 0;
        _this.animIsRunning = false;
        _this.state = {
            currentActive: -2,
        };
        _this.onTransitionEnd = function () {
            clearTimeout(_this.animTimer);
            if (_this.ref && _this.ref.current) {
                var dom = _this.ref.current;
                var line = dom.querySelector('.x-tabs__line');
                for (var i = 0; i < dom.children.length; i++) {
                    if (dom.children[i].classList.contains('x-tabs--active')) {
                        dom.children[i].classList.add('x-tabs--line');
                        _this.setState({
                            currentActive: i,
                        });
                        break;
                    }
                }
                if (line) {
                    line.setAttribute('style', 'display: none;');
                }
                _this.animIsRunning = false;
            }
        };
        return _this;
    }
    Tabs.prototype.componentDidMount = function () {
        if (this.ref && this.ref.current) {
            var dom = this.ref.current;
            for (var i = 0; i < dom.children.length; i++) {
                if (dom.children[i].classList.contains('x-tabs--active')) {
                    dom.children[i].classList.add('x-tabs--line');
                    this.setState({
                        currentActive: i,
                    });
                    break;
                }
            }
        }
    };
    Tabs.prototype.componentDidUpdate = function () {
        if (this.animIsRunning) {
            return;
        }
        if (this.ref && this.ref.current) {
            var dom = this.ref.current;
            var line_1 = dom.querySelector('.x-tabs__line');
            var currentX_1 = 0;
            var targetX_1 = 0;
            var moveLine = function () {
                var duration = 0.3;
                if (Math.abs(targetX_1 - currentX_1) < 90) {
                    duration = 0.15;
                }
                line_1.setAttribute('style', "transform: translate(" + targetX_1 + "px, 0); transition: transform " + duration + "s ease-out;");
                if (line_1.firstChild) {
                    ;
                    line_1.firstChild.setAttribute('style', "animation: __x_tabs_line_scale " + duration + "s ease-out");
                }
            };
            for (var _i = 0, _a = dom.children; _i < _a.length; _i++) {
                var item = _a[_i];
                if (item.classList.contains('x-tabs--active')) {
                    var cur = dom.children[this.state.currentActive];
                    currentX_1 = cur
                        ? cur.getBoundingClientRect().left + cur.getBoundingClientRect().width / 2
                        : -300;
                    targetX_1 = item.getBoundingClientRect().left + item.getBoundingClientRect().width / 2;
                    if (currentX_1 !== targetX_1 && line_1) {
                        this.animIsRunning = true;
                        line_1.setAttribute('style', "transform: translate(" + currentX_1 + "px, 0);");
                        clearTimeout(this.animTimer);
                        this.animTimer = setTimeout(this.onTransitionEnd, 400);
                        setTimeout(moveLine, 10);
                    }
                    break;
                }
            }
        }
    };
    Tabs.prototype.render = function () {
        var _this = this;
        var _a = this.props, className = _a.className, children = _a.children, active = _a.active, onClick = _a.onClick, shrink = _a.shrink, otherProps = __rest(_a, ["className", "children", "active", "onClick", "shrink"]);
        var composeClassName = cn('x-tabs', {
            'x-tabs--shrink': shrink,
        }, className);
        var composeChildren = [];
        if (Array.isArray(children)) {
            composeChildren.push.apply(composeChildren, children);
        }
        else {
            composeChildren.push(children);
        }
        composeChildren = composeChildren.map(function (res, index) {
            var act = _this.props.hasOwnProperty('active') && res.props.value === active;
            return React.cloneElement(res, {
                active: act,
                key: index,
                value: res.props.value,
                onClick: function (value) {
                    if (_this.animIsRunning) {
                        return;
                    }
                    onClick(value);
                },
                children: res.props.children,
            });
        });
        if (shrink) {
            return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
                React.createElement("div", { className: "x-tabs--scroller" },
                    React.createElement("div", { className: "x-tabs__inner", ref: this.ref },
                        React.createElement("sub", { className: "x-tabs__line", style: { display: 'none' }, onTransitionEnd: this.onTransitionEnd },
                            React.createElement("i", null)),
                        composeChildren))));
        }
        return (React.createElement("div", __assign({}, otherProps, { className: composeClassName, ref: this.ref }),
            React.createElement("sub", { className: "x-tabs__line", style: { display: 'none' }, onTransitionEnd: this.onTransitionEnd },
                React.createElement("i", null)),
            composeChildren));
    };
    return Tabs;
}(React.PureComponent));
Tabs.Item = TabsItem;
export default Tabs;
